@@ -1,4 +1,4 @@
-"model.average.marklist"<- function(x,...,parameter=NULL,data=NULL,vcv=FALSE,drop=TRUE,indices=NULL,revised=TRUE)
+"model.average.marklist"<- function(x,parameter=NULL,data=NULL,vcv=FALSE,drop=TRUE,indices=NULL,revised=TRUE,...)
 {
 # Computes model averaged real parameter estimates and their std errors for the values specified by
 # parameter (eg "Psi", "p" etc) using the models contained in model.list.  If parameter=NULL,
